@@ -3,7 +3,11 @@ adjCov <- function(object, id){
 if(object$PL!="P") stop("This correction does not currently work for models with asymmetric links.")
 
 Vb     <- object$Vb 
-scores <- cbind( c(object$fit$dl.dbe1)*object$X1, c(object$fit$dl.dbe2)*object$X2, object$fit$dl.drho )
+
+if(is.null(object$X3) )  mul <- 1
+if(!is.null(object$X3) ) mul <- object$X3[object$good,]
+
+scores <- cbind( c(object$fit$dl.dbe1)*object$X1[object$good,], c(object$fit$dl.dbe2)*object$X2[object$good,], object$fit$dl.drho*mul )
 scores <- aggregate.data.frame(scores,by=list(id),FUN=sum)[,-1]
 nclusters <- dim(scores)[1]
 meat   <- (nclusters-1)*var(scores)
@@ -23,4 +27,6 @@ object
 #                  "sED" (symmetric eigen-decomposition).}  
 #\item{BivD, nu, PL, sel}{These are used for internal calculations.}
 #\item{IV}{IV = NULL  An instrumental variable can be used if available. This can be either a binary or categorical variable. The use of a 
-#          continuous IV is not supported.} 
\ No newline at end of file
+#
+#          continuous IV is not supported.} 
+# importFrom(CDVine,BiCopCDF,BiCopHfunc,BiCopPDF,BiCopMetaContour)
\ No newline at end of file
