@@ -1,13 +1,14 @@
 plot.SemiParBIVProbit <- function(x, eq, ...){
 
  if(eq==1){ ss.plot <- x$gam1
-            ind <- (1:length(ss.plot$coefficients)) 
+            ind <- 1:x$X1.d2 
             } 
  if(eq==2){ ss.plot <- x$gam2
-            fir <- length(x$gam1$coefficients) + 1 
-            sec <- fir - 1 + length(ss.plot$coefficients)
-            ind <- fir:sec }
-                                   
+            ind <- (x$X1.d2+1):(x$X1.d2+x$X2.d2) 
+            }
+ if(eq==3){ ss.plot <- x$gam3
+            ind <- (x$X1.d2+x$X2.d2+1):(x$X1.d2+x$X2.d2+x$X3.d2) }
+                                    
            ss.plot$coefficients <- x$coefficients[ind]
            ss.plot$Vp <- x$Vb[ind,ind]
            ss.plot$edf <- diag(x$F)[ind]
